==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/KeyAction.h <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef __KEYACTION_H__INCLUDED__
#define __KEYACTION_H__INCLUDED__
#include "Scene/KeyListener.h"

class ActionCommand;
class ActionFO;
class KeyEntry;
class SceneMediator;

/**
 * キー入力を受け取って、アクションシーケンスを実行する
 */
class KeyAction : public KeyListener
{
private:
    ActionCommand* commandPressed;
    ActionCommand* commandReleased;
    ActionFO* target;
public:
    KeyAction(ActionFO* target, ActionCommand* pressed, ActionCommand* released);
    KeyAction(ActionFO* target, KeyEntry* keyEntry);
    void setTarget(ActionFO* target);
    void setCommandPressed(ActionCommand* command);
    void setCommandReleased(ActionCommand* command);
    virtual bool keyPressed(SceneMediator* mediator);
    virtual bool keyReleased(SceneMediator* mediator);
    void destroy();
    void destroy(SceneMediator* mediator);
    KeyAction* clone();
    void entry(SceneMediator* mediator);
};
#endif

==> daikon-1.1.tar.gz: daikon-1.1/src/KeyAction.h <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef __KEYACTION_H__INCLUDED__
#define __KEYACTION_H__INCLUDED__
#include "Scene/KeyListener.h"

class ActionCommand;
class ActionFO;
class KeyEntry;
class SceneMediator;

/**
 * キー入力を受け取って、アクションシーケンスを実行する
 */
class KeyAction : public KeyListener
{
private:
    ActionCommand* commandPressed;
    ActionCommand* commandReleased;
    ActionFO* target;
public:
    void setTarget(ActionFO* target);
    void setCommandPressed(ActionCommand* command);
    void setCommandReleased(ActionCommand* command);
    virtual bool keyPressed(SceneMediator* mediator);
    virtual bool keyReleased(SceneMediator* mediator);
    static KeyAction* create(ActionFO* target, ActionCommand* pressed, ActionCommand* released);
    static KeyAction* create(ActionFO* target, KeyEntry* keyEntry);
    void destroy();
    void destroy(SceneMediator* mediator);
    KeyAction* clone();
    void entry(SceneMediator* mediator);
};
#endif
